@@ -503,7 +503,10 @@ class Shell:
     def check_kernel_update_reboot_required(self):
         """Checks if the pi needs to be rebooted since the last kernel update"""
         if not self.exists("/lib/modules/{}".format(self.release())):
-            self.error("OS has not been rebooted since last kernel update.")
+            self.error(
+                "OS has not been rebooted since last kernel update. "
+                "Please reboot and re-run the script."
+            )
             self.prompt_reboot()
 
     # pylint: enable=invalid-name
